is_working_tree_clean

Function is_working_tree_clean 

pub fn is_working_tree_clean(path: &Path) -> Result<bool>
Errors

Returns an error if the path is not a git repository or if the status check fails.