pub struct Repository { /* private fields */ }Implementations
Sourceimpl Repository
impl Repository
Sourceimpl Repository
impl Repository
Sourcepub fn changed_files(
&self,
base: Option<&str>,
head: &str,
) -> Result<Vec<FileChange>>
pub fn changed_files( &self, base: Option<&str>, head: &str, ) -> Result<Vec<FileChange>>
Errors
Returns GitError::RefNotFound if either base or head cannot be resolved.
Sourcepub fn uncommitted_changes(&self) -> Result<Vec<FileChange>>
pub fn uncommitted_changes(&self) -> Result<Vec<FileChange>>
Errors
Returns GitError::RefNotFound if HEAD cannot be resolved.
Sourcepub fn changed_files_from_head(&self, base: &str) -> Result<Vec<FileChange>>
pub fn changed_files_from_head(&self, base: &str) -> Result<Vec<FileChange>>
Errors
Returns GitError::RefNotFound if the base reference cannot be resolved.
Sourceimpl Repository
impl Repository
Sourcepub fn delete_file(&self, path: &Path) -> Result<()>
pub fn delete_file(&self, path: &Path) -> Result<()>
Errors
Returns GitError::FileDelete if the file cannot be deleted.
Sourcepub fn delete_files(&self, paths: &[&Path]) -> Result<()>
pub fn delete_files(&self, paths: &[&Path]) -> Result<()>
Errors
Returns GitError::FileDelete if any file cannot be deleted.
Sourceimpl Repository
impl Repository
Sourceimpl Repository
impl Repository
Sourceimpl Repository
impl Repository
Sourcepub fn current_branch(&self) -> Result<String>
pub fn current_branch(&self) -> Result<String>
Errors
Returns GitError::DetachedHead if HEAD is not on a branch.
Sourcepub fn is_working_tree_clean(&self) -> Result<bool>
pub fn is_working_tree_clean(&self) -> Result<bool>
Errors
Returns an error if the git status operation fails.
Sourcepub fn require_clean_working_tree(&self) -> Result<()>
pub fn require_clean_working_tree(&self) -> Result<()>
Errors
Returns GitError::DirtyWorkingTree if there are uncommitted changes.
Sourceimpl Repository
impl Repository